@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless;
-$Footprintless::VERSION = '1.03';
+$Footprintless::VERSION = '1.04';
 # ABSTRACT: A utility for managing systems with minimal installs
 # PODNAME: Footprintless
 
@@ -54,7 +54,7 @@ sub entities {
 sub _init {
     my ( $self, %options ) = @_;
 
-    $logger->debug('creating new Footprintless');
+    $logger->debugf( 'creating new Footprintless: %s', \%options );
 
     if ( $options{factory} ) {
         $self->{factory} = $options{factory};
@@ -158,6 +158,11 @@ sub service {
     $self->{factory}->service(@args);
 }
 
+sub tunnel {
+    my ( $self, @args ) = @_;
+    $self->{factory}->tunnel(@args);
+}
+
 sub _split_dirs {
     my ($dirs_string) = @_;
 
@@ -184,7 +189,7 @@ Footprintless - A utility for managing systems with minimal installs
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -514,6 +519,11 @@ this footprintless instance.
 
 =back
 
+=head2 tunnel($coordinate, %options)
+
+Returns a new instance of L<Footprintless::Tunnel> preconfigured 
+for C<$coordinate>. 
+
 =head1 AUTHOR
 
 Lucas Theisen <lucastheisen@pastdev.com>
