@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Command;
-$Footprintless::Command::VERSION = '1.03';
+$Footprintless::Command::VERSION = '1.04';
 # ABSTRACT: A factory for building common commands
 # PODNAME: Footprintless::Command
 
@@ -126,7 +126,7 @@ sub cp_command {
                 _sudo_command(
                     $destination_command_options
                         && $destination_command_options->get_sudo_username(),
-                    "tar -x -C $destination_path"
+                    "tar --no-overwrite-dir -x -C $destination_path"
                 )
             );
 
@@ -364,7 +364,7 @@ sub wrap {
 }
 
 package Footprintless::Command::CommandOptions;
-$Footprintless::Command::CommandOptions::VERSION = '1.03';
+$Footprintless::Command::CommandOptions::VERSION = '1.04';
 sub new {
     return bless( {}, shift )->_init(@_);
 }
@@ -433,7 +433,7 @@ Footprintless::Command - A factory for building common commands
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
