@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Factory;
-$Footprintless::Factory::VERSION = '1.03';
+$Footprintless::Factory::VERSION = '1.04';
 # ABSTRACT: The default factory for footprintless modules
 # PODNAME: Footprintless::Factory
 
@@ -86,6 +86,7 @@ sub _init {
     $self->{agent}                   = $options{agent};
     $self->{command_options_factory} = $options{command_options_factory};
     $self->{command_runner}          = $options{command_runner};
+    $self->{localhost}               = $options{localhost};
     $self->{resource_manager}        = $options{resource_manager};
 
     $self->{plugins} = [];
@@ -157,6 +158,13 @@ sub service {
     return Footprintless::Service->new( $self, $coordinate, %options );
 }
 
+sub tunnel {
+    my ( $self, $coordinate, %options ) = @_;
+
+    require Footprintless::Tunnel;
+    return Footprintless::Tunnel->new( $self, $coordinate, %options );
+}
+
 1;
 
 __END__
@@ -169,7 +177,7 @@ Footprintless::Factory - The default factory for footprintless modules
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 DESCRIPTION
 
@@ -333,6 +341,11 @@ this footprintless instance.
 
 =back
 
+=head2 tunnel($coordinate, %options)
+
+Returns a new instance of L<Footprintless::Tunnel> preconfigured 
+for C<$coordinate>. 
+
 =head1 AUTHOR
 
 Lucas Theisen <lucastheisen@pastdev.com>
