@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Log;
-$Footprintless::Log::VERSION = '1.03';
+$Footprintless::Log::VERSION = '1.04';
 # ABSTRACT: A log manager
 # PODNAME: Footprintless::Log
 
@@ -157,7 +157,7 @@ sub _runner_options {
             my $handle = $runner_options->{out_handle};
             $options->{out_callback} = sub {
                 my ($line) = @_;
-                print( $handle $line ) if ($handle);
+                print( $handle "$line\n" ) if ($handle);
                 die('until found') if ( $line =~ $until );
             };
         }
@@ -209,7 +209,7 @@ Footprintless::Log - A log manager
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
