@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Overlay;
-$Footprintless::Overlay::VERSION = '1.03';
+$Footprintless::Overlay::VERSION = '1.04';
 # ABSTRACT: An overlay manager
 # PODNAME: Footprintless::Overlay
 
@@ -21,6 +21,8 @@ use Footprintless::Util qw(
     temp_dir
 );
 use Log::Any;
+use File::Find;
+use File::Spec;
 use Template::Resolver;
 use Template::Overlay;
 
@@ -91,7 +93,18 @@ sub initialize {
 
 sub _initialize {
     my ( $self, $base_dir, $template_dir, $to_dir ) = @_;
-    $self->_overlay($base_dir)->overlay( $template_dir, to => $to_dir );
+    $self->_overlay($base_dir)->overlay(
+        $template_dir,
+        to       => $to_dir,
+        resolver => sub {
+            my ( $template, $destination ) = @_;
+            if ( $template =~ /\/\.footprintless$/ ) {
+                $self->_resolve_footprintless( $template, $destination );
+                return 1;
+            }
+            return 0;
+        }
+    );
 }
 
 sub _local_with_dirs_template {
@@ -128,6 +141,22 @@ sub _resolver {
     return Template::Resolver->new( $resolver_spec, @resolver_opts );
 }
 
+sub _resolve_footprintless {
+    my ( $self, $template, $footprintless_path ) = @_;
+    my $destination = ( File::Spec->splitpath($footprintless_path) )[1];
+    $logger->debugf( "resolving [%s]->[%s]", $template, $destination );
+
+    my $spec = do($template) || return;
+    croak("invalid $template") unless ( ref($spec) eq 'HASH' );
+
+    if ( $spec->{resources} ) {
+        my $resource_manager = $self->{factory}->resource_manager();
+        foreach my $resource ( keys( %{ $spec->{resources} } ) ) {
+            $resource_manager->download( $spec->{resources}{$resource}, to => $destination );
+        }
+    }
+}
+
 sub update {
     my ( $self, %options ) = @_;
 
@@ -166,7 +195,7 @@ Footprintless::Overlay - An overlay manager
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
