@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Service;
-$Footprintless::Service::VERSION = '1.03';
+$Footprintless::Service::VERSION = '1.04';
 # ABSTRACT: Performs an action on a service.
 # PODNAME: Footprintless::Service
 
@@ -26,7 +26,8 @@ sub new {
 }
 
 sub kill {
-    $_[0]->execute('kill');
+    my ( $self, %options ) = @_;
+    $self->execute( 'kill', %options );
 }
 
 sub _command {
@@ -48,21 +49,23 @@ sub _command {
             my $pid_file = $self->{spec}{pid_file};
             my $pid_command =
                 $pid_file
-                ? "cat $pid_file"
+                ? command(
+                "cat $pid_file",
+                $self->{command_options}->clone(
+                    hostname     => undef,
+                    ssh          => undef,
+                    ssh_username => undef,
+                )
+                )
                 : $self->{spec}{pid_command};
             if ( $action eq 'kill' ) {
                 return "kill -KILL \$($pid_command)";
             }
             elsif ( $action eq 'status' ) {
                 my $command_name = $actions_spec->{command_name} || $command || 'command';
-                return batch_command(
-                    "pid=\$($pid_command)",
-                    "if [[ -n \$pid ]] && \$(kill -0 \$pid 2> /dev/null)",
-                    "then printf '$command_name (pid \%s) is running...' \"\$pid\"",
-                    "else printf '$command_name is stopped...'",
-                    "fi",
-                    { subshell => 'bash -c ' }
-                );
+                return command( "kill -0 \$($pid_command) 2> /dev/null "
+                        . "&& echo '$command_name is running' "
+                        . "|| echo '$command_name is stopped'" );
             }
             else {
                 invalid_entity( $self->{coordinate}, "use_pid not supported for [$action]" );
@@ -76,10 +79,16 @@ sub _command {
 }
 
 sub execute {
-    my ( $self, $action ) = @_;
+    my ( $self, $action, %options ) = @_;
+
+    my $runner_options =
+          %options && $options{runner_options}
+        ? $options{runner_options}
+        : { out_handle => \*STDOUT };
+
     $self->{command_runner}
         ->run_or_die( command( $self->_command($action), $self->{command_options} ),
-        { out_handle => \*STDOUT } );
+        $runner_options );
 }
 
 sub _init {
@@ -98,15 +107,18 @@ sub _init {
 }
 
 sub start {
-    $_[0]->execute('start');
+    my ( $self, %options ) = @_;
+    $self->execute( 'start', %options );
 }
 
 sub status {
-    $_[0]->execute('status');
+    my ( $self, %options ) = @_;
+    $self->execute( 'status', %options );
 }
 
 sub stop {
-    $_[0]->execute('stop');
+    my ( $self, %options ) = @_;
+    $self->execute( 'stop', %options );
 }
 
 1;
@@ -121,7 +133,7 @@ Footprintless::Service - Performs an action on a service.
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
