@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Util;
-$Footprintless::Util::VERSION = '1.03';
+$Footprintless::Util::VERSION = '1.04';
 # ABSTRACT: A utility method package for common functionality in Footprintless
 # PODNAME: Footprintless::Util
 
@@ -24,6 +24,7 @@ our @EXPORT_OK = qw(
     slurp
     spurt
     temp_dir
+    temp_file
 );
 
 my $logger = Log::Any->get_logger();
@@ -83,10 +84,10 @@ sub exit_due_to {
     if ( ref($dollar_at)
         && $dollar_at->isa('Footprintless::CommandRunner::ExecutionException') )
     {
-        $@->exit($verbose);
+        $dollar_at->exit($verbose);
     }
     else {
-        print( STDERR "$@" );
+        print( STDERR "$dollar_at\n" );
         exit 255;
     }
 }
@@ -188,7 +189,9 @@ sub slurp {
     my ($file) = @_;
 
     # http://www.perl.com/pub/2003/11/21/slurp.html
-    return do { local ( @ARGV, $/ ) = $file; <> };
+    return $file
+        ? do { local ( @ARGV, $/ ) = $file; <> }
+        : do { local $/; <STDIN> };
 }
 
 sub spurt {
@@ -203,7 +206,21 @@ sub spurt {
 sub temp_dir {
     require File::Temp;
     File::Temp->safe_level( File::Temp::HIGH() );
-    return File::Temp->newdir();
+    my $temp = File::Temp->newdir();
+    if ( !chmod( 0700, $temp ) ) {
+        croak("unable to create secure temp file");
+    }
+    return $temp;
+}
+
+sub temp_file {
+    require File::Temp;
+    File::Temp->safe_level( File::Temp::HIGH() );
+    my $temp = File::Temp->new();
+    if ( !chmod( 0600, $temp ) ) {
+        croak("unable to create secure temp file");
+    }
+    return $temp;
 }
 
 1;
@@ -218,7 +235,7 @@ Footprintless::Util - A utility method package for common functionality in Footp
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -323,14 +340,20 @@ is available, and a L<url provider|Footprintless::Resource::UrlProvider>
 in that order.  If C<$agent> is provided, it will be passed on to the 
 providers.
 
-=head2 slurp($file)
+=head2 slurp([$file])
 
-Reads the entire contents of C<$file> in one gulp.
+Reads the entire contents of C<$file> in one gulp.  If C<$file> is 
+omitted, then it will read C<STDIN>.
 
 =head2 spurt($content, $file, %options)
 
 Writes C<$content> to C<$file>.  The available options are:
 
+=head2 temp_file()
+
+Creates a new temporary file with C<safe_level> set to 
+C<HIGH>.  Returns the new L<File::Temp> object.
+
 =head2 temp_dir()
 
 Creates a new temporary directory with C<safe_level> set to 
